==> packetfence_10.0.0+20200416135032+136717529+0009+v10.0.0+stretch1.tar.gz: packetfence/html/pfappserver/root/static.alt/src/views/Reports/_router/index.js <==
import store from '@/store'
import ReportsIndex from '../'
import ReportsStore from '../_store'

const StandardReportChart = () => import(/* webpackChunkName: "Reports" */ '../_components/StandardReportChart')
const DynamicReportChart = () => import(/* webpackChunkName: "Reports" */ '../_components/DynamicReportChart')

const route = {
  path: '/reports',
  name: 'reports',
  redirect: '/reports/standard/chart/os',
  component: ReportsIndex,
  beforeEnter: (to, from, next) => {
    if (!store.state.$_reports) {
      // Register store module only once
      store.registerModule('$_reports', ReportsStore)
    }
    next()
  },
  children: [
    {
      path: 'standard/chart/:path([a-zA-Z0-9-_/]+)/:start_datetime?/:end_datetime?',
      name: 'standardReportChart',
      component: StandardReportChart,
      props: (route) => ({
        path: route.params.path,
        start_datetime: route.params.start_datetime,
        end_datetime: route.params.end_datetime
      }),
      meta: {
        can: 'read reports',
        fail: { path: '/auditing', replace: true }
      }
    },
    {
      path: 'dynamic/chart/:id([a-zA-Z0-9-_ ]+)',
      name: 'dynamicReportChart',
      component: DynamicReportChart,
      props: (route) => ({ storeName: '$_reports', id: route.params.id, query: route.query.query }),
      beforeEnter: (to, from, next) => {
        store.dispatch('$_reports/getReport', to.params.id).then(() => {
          next()
        })
      },
      meta: {
        can: 'read reports',
        fail: { path: '/auditing', replace: true }
      }
    }
  ]
}

export default route

==> packetfence_10.1.0+20200617132524+157294356+0009+v10.1.0+stretch1.tar.gz: packetfence/html/pfappserver/root/static.alt/src/views/Reports/_router/index.js <==
import acl from '@/utils/acl'
import store from '@/store'
import ReportsIndex from '../'
import ReportsStore from '../_store'

const StandardReportChart = () => import(/* webpackChunkName: "Reports" */ '../_components/StandardReportChart')
const DynamicReportChart = () => import(/* webpackChunkName: "Reports" */ '../_components/DynamicReportChart')

const route = {
  path: '/reports',
  name: 'reports',
  redirect: '/reports/standard/chart/os',
  component: ReportsIndex,
  meta: {
    can: () => {
      return acl.$some('read', ['reports']) // has ACL for 1+ children
    },
    fail: { path: '/auditing', replace: true }, // no ACL in this view, redirect to next sibling
    transitionDelay: 300 * 2 // See _transitions.scss => $slide-bottom-duration
  },
  beforeEnter: (to, from, next) => {
    if (!store.state.$_reports) {
      // Register store module only once
      store.registerModule('$_reports', ReportsStore)
    }
    next()
  },
  children: [
    {
      path: 'standard/chart/:path([a-zA-Z0-9-_/]+)/:start_datetime?/:end_datetime?',
      name: 'standardReportChart',
      component: StandardReportChart,
      props: (route) => ({
        path: route.params.path,
        start_datetime: route.params.start_datetime,
        end_datetime: route.params.end_datetime
      }),
      meta: {
        can: 'read reports',
        fail: { name: 'dynamicReportChart', replace: true } // redirect to next sibling
      }
    },
    {
      path: 'dynamic/chart/:id([a-zA-Z0-9-_ ]+)',
      name: 'dynamicReportChart',
      component: DynamicReportChart,
      props: (route) => ({ storeName: '$_reports', id: route.params.id, query: route.query.query }),
      beforeEnter: (to, from, next) => {
        store.dispatch('$_reports/getReport', to.params.id).then(() => {
          next()
        })
      },
      meta: {
        can: 'read reports',
        fail: { name: 'standardReportChart', replace: true } // redirect to first sibling
      }
    }
  ]
}

export default route
